.. tw.jqgrid documentation master file.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tw.jqgrid documentation!
=========================================================

Contents
--------

.. toctree::
   :maxdepth: 2


:class:`tw.jqgrid.Jqgrid`
----------------------------------------------------------

.. autoclass:: tw.jqgrid.Jqgrid
.. widgetbrowser:: tw.jqgrid.Jqgrid

.. note::
    See http://toscawidgets.org/documentation/WidgetBrowser to learn how to
    customize the ``widgetbrowser`` directive.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
